def run_file(path):
    try:
        with open(path, "r") as f:
            code = f.read()

        print("Running A# program:")
        print(code)

    except FileNotFoundError:
        print("File not found:", path)


# asharp/cli.py

import sys
import argparse
from .interpreter import run_file
from .compiler import compile_file


def main():
    parser = argparse.ArgumentParser(
        prog="ash",
        description="A# Programming Language CLI"
    )

    subparsers = parser.add_subparsers(dest="command")

    # run command
    run_parser = subparsers.add_parser("run", help="Run an A# file")
    run_parser.add_argument("file", help="A# source file")

    # compile command
    compile_parser = subparsers.add_parser("compile", help="Compile an A# file")
    compile_parser.add_argument("file", help="A# source file")

    # default argument (ash file.ash)
    parser.add_argument("file", nargs="?", help="A# source file")

    args = parser.parse_args()

    # ash file.ash
    if args.file and args.command is None:
        run_file(args.file)
        return

    if args.command == "run":
        run_file(args.file)

    elif args.command == "compile":
        compile_file(args.file)

    else:
        parser.print_help()


if __name__ == "__main__":
    main()


from setuptools import setup, find_packages
from pathlib import Path

# reads README.md
readme_path = Path("README.md")
long_description = readme_path.read_text(encoding="utf-8")

setup(
    name="asharp",
    version="0.1.0",
    description="A# programming language",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Intel",
    license="GPL-3.0",
    packages=find_packages(),
    python_requires=">=3.10",
    entry_points={
        "console_scripts": [
            "asharp=asharp.cli:main",
        ],
    },
)

# note for people forking this project:

# change description and author if you're forking this project

# also update version names in pyproject.toml and this file when you make changes to your project

# btw add more things like dependencies on pyproject.toml if you want any

# also add a license file with the license text if you want any other license than GPL 3.0

# feel free to asks me any questions about the code or the project btw


"""
A# Programming Language

A# is an experimental programming language project designed to explore
new programming language concepts and tooling.

This package provides the A# interpreter, compiler interface, and CLI tools.
"""

__title__ = "asharp"
__version__ = "0.1.0"
__author__ = "Intel"
__license__ = "GPL-3.0" # yes this is the license we use

# public api
from .interpreter import run_file
from .compiler import compile_file

__all__ = [
    "run_file",
    "compile_file"
]